@@ -1,27 +1,11 @@
-# Copyright (c) 2016 Uber Technologies, Inc.
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-# http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
-
 import unittest
-from collections import namedtuple
 from itertools import product
 
 import mock
 import pytest
 from async_jaeger import Span, SpanContext, Tracer, ConstSampler
 from async_jaeger.codecs import (
-    BaseCodec, TextCodec, BinaryCodec,
+    TextCodec, BinaryCodec,
     span_context_from_string,
     span_context_to_string,
 )
@@ -36,13 +20,6 @@ from opentracing.propagation import (
 
 class TestCodecs(unittest.TestCase):
 
-    def test_abstract_codec(self):
-        codec = BaseCodec()
-        with self.assertRaises(NotImplementedError):
-            codec.inject({}, {})
-        with self.assertRaises(NotImplementedError):
-            codec.extract({})
-
     def test_wrong_carrier(self):
         codec = TextCodec()
         with self.assertRaises(InvalidCarrierException):
@@ -225,7 +202,6 @@ class TestCodecs(unittest.TestCase):
         assert context.parent_id == (1 << 64) - 1
         assert context.parent_id > 0
 
-
     def test_binary_codec(self):
         codec = BinaryCodec()
         with self.assertRaises(InvalidCarrierException):
@@ -453,7 +429,6 @@ def test_debug_id():
     )
     carrier = {debug_header: 'Coraline'}
     context = tracer.extract(Format.TEXT_MAP, carrier)
-    assert context.is_debug_id_container_only
     assert context.debug_id == 'Coraline'
     span = tracer.start_span('test', child_of=context)
     assert span.is_debug()
